@@ -301,6 +301,10 @@ const (
 	ArgForwardingRules = "forwarding-rules"
 	// ArgHTTPIdleTimeoutSeconds is the http idle time out configuration for the load balancer
 	ArgHTTPIdleTimeoutSeconds = "http-idle-timeout-seconds"
+	// ArgAllowList is the list of firewall rules for ALLOWING traffic to the loadbalancer
+	ArgAllowList = "allow-list"
+	// ArgDenyList is a list of firewall rules for DENYING traffic to the loadbalancer
+	ArgDenyList = "deny-list"
 
 	// ArgFirewallName is a name of the firewall.
 	ArgFirewallName = "name"
@@ -432,4 +436,18 @@ const (
 
 	// ArgAlertPolicySlackURLs are the Slack URLs to send alerts to.
 	ArgAlertPolicySlackURLs = "slack-urls"
+
+	// ArgTokenValidationServer is the server used to validate an OAuth token
+	ArgTokenValidationServer = "token-validation-server"
+
+	// ArgTokenScopeNamespace is the namespace for a scope
+	ArgTokenScopeNamespace = "namespace"
+	// ArgTokenExpirySeconds is the number of seconds from when a token was create that it will expire
+	ArgTokenExpirySeconds = "expiry-seconds"
+	// ArgTokenExpiresIn is the duration until a token expires
+	ArgTokenExpiresIn = "expires-in"
+	// ArgTokenScopes is a list of token scopes
+	ArgTokenScopes = "scopes"
+	// ArgTokenUpdatedName is the name to used to update a token
+	ArgTokenUpdatedName = "updated-name"
 )
