@@ -14,7 +14,6 @@ limitations under the License.
 package commands
 
 import (
-	"github.com/spf13/cobra"
 	"io/ioutil"
 	"sort"
 	"testing"
@@ -25,6 +24,7 @@ import (
 	"github.com/digitalocean/doctl/internal/apps/builder"
 	"github.com/digitalocean/godo"
 	"github.com/golang/mock/gomock"
+	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"github.com/stretchr/testify/assert"
 )
@@ -185,6 +185,8 @@ type tcMocks struct {
 	appBuilderFactory     *builder.MockComponentBuilderFactory
 	appBuilder            *builder.MockComponentBuilder
 	appDockerEngineClient *builder.MockDockerEngineClient
+	oauth                 *domocks.MockOAuthService
+	tokens                *domocks.MockTokensService
 }
 
 func withTestClient(t *testing.T, tFn testFn) {
@@ -229,6 +231,8 @@ func withTestClient(t *testing.T, tFn testFn) {
 		appBuilderFactory:     builder.NewMockComponentBuilderFactory(ctrl),
 		appBuilder:            builder.NewMockComponentBuilder(ctrl),
 		appDockerEngineClient: builder.NewMockDockerEngineClient(ctrl),
+		oauth:                 domocks.NewMockOAuthService(ctrl),
+		tokens:                domocks.NewMockTokensService(ctrl),
 	}
 
 	testConfig := doctl.NewTestConfig()
@@ -282,6 +286,8 @@ func withTestClient(t *testing.T, tFn testFn) {
 		Apps:              func() do.AppsService { return tm.apps },
 		Monitoring:        func() do.MonitoringService { return tm.monitoring },
 		Serverless:        func() do.ServerlessService { return tm.serverless },
+		OAuth:             func() do.OAuthService { return tm.oauth },
+		Tokens:            func() do.TokensService { return tm.tokens },
 	}
 
 	tFn(config, tm)
