@@ -44,6 +44,7 @@ import (
 type ServerlessCredentials struct {
 	APIHost     string                                     `json:"currentHost"`
 	Namespace   string                                     `json:"currentNamespace"`
+	Label       string                                     `json:"label"`
 	Credentials map[string]map[string]ServerlessCredential `json:"credentials"`
 }
 
@@ -176,13 +177,18 @@ type ServerlessTriggerGetResponse struct {
 	Trigger ServerlessTrigger `json:"Trigger,omitempty"`
 }
 
+type UpdateTriggerRequest struct {
+	IsEnabled        bool                     `json:"is_enabled"`
+	ScheduledDetails *TriggerScheduledDetails `json:"scheduled_details,omitempty"`
+}
+
 // ServerlessTrigger is the form used in list and get responses by the triggers API
 type ServerlessTrigger struct {
 	Namespace        string                   `json:"namespace,omitempty"`
 	Function         string                   `json:"function,omitempty"`
 	Type             string                   `json:"type,omitempty"`
 	Name             string                   `json:"name,omitempty"`
-	IsEnabled        bool                     `json:"is_enabled,omitempty"`
+	IsEnabled        bool                     `json:"is_enabled"`
 	CreatedAt        time.Time                `json:"created_at,omitempty"`
 	UpdatedAt        time.Time                `json:"updated_at,omitempty"`
 	ScheduledDetails *TriggerScheduledDetails `json:"scheduled_details,omitempty"`
@@ -214,12 +220,14 @@ type ServerlessService interface {
 	CleanNamespace() error
 	ListTriggers(context.Context, string) ([]ServerlessTrigger, error)
 	GetTrigger(context.Context, string) (ServerlessTrigger, error)
+	UpdateTrigger(context.Context, string, *UpdateTriggerRequest) (ServerlessTrigger, error)
 	DeleteTrigger(context.Context, string) error
 	WriteCredentials(ServerlessCredentials) error
 	ReadCredentials() (ServerlessCredentials, error)
 	GetHostInfo(string) (ServerlessHostInfo, error)
 	CheckServerlessStatus() error
 	InstallServerless(string, bool) error
+	ListPackages() ([]whisk.Package, error)
 	DeletePackage(string, bool) error
 	GetFunction(string, bool) (whisk.Action, []FunctionParameter, error)
 	ListFunctions(string, int, int) ([]whisk.Action, error)
@@ -251,10 +259,8 @@ type serverlessService struct {
 }
 
 const (
-	// Minimum required version of the serverless plugin code.  The first part is
-	// the version of the incorporated functions deployer and the second part is the
-	// version of the bridge code in the sandbox plugin repository.
-	minServerlessVersion = "5.0.14-2.0.0"
+	// Minimum required version of the functions deployer plugin code.
+	minServerlessVersion = "5.0.18"
 
 	// The version of nodejs to download alongsize the plugin download.
 	nodeVersion = "v16.13.0"
@@ -411,6 +417,7 @@ func (s *serverlessService) InstallServerless(leafCredsDir string, upgrading boo
 	// that might be on a separate file system, meaning that the final install step
 	// will require an additional copy rather than a simple rename.
 
+	os.Mkdir(filepath.Dir(serverlessDir), 0700) // in case using config dir and it doesn't exist yet
 	tmp, err := ioutil.TempDir(filepath.Dir(serverlessDir), "sbx-install")
 	if err != nil {
 		return err
@@ -621,6 +628,7 @@ func executeNamespaceRequest(ctx context.Context, s *serverlessService, req *htt
 	ans := ServerlessCredentials{
 		APIHost:     host,
 		Namespace:   namespace,
+		Label:       decoded.Namespace.Label,
 		Credentials: map[string]map[string]ServerlessCredential{host: {namespace: credential}},
 	}
 	return ans, nil
@@ -726,7 +734,7 @@ func (s *serverlessService) CleanNamespace() error {
 	}
 
 	// Deletes all functions
-	fns, err := s.ListFunctions("", 0, 0)
+	fns, err := s.ListFunctions("", 0, 200)
 	if err != nil {
 		return err
 	}
@@ -745,6 +753,19 @@ func (s *serverlessService) CleanNamespace() error {
 		}
 	}
 
+	// Now delete all packages.  Since the functions are presumably gone, the packages can be deleted non-recursively.
+	pkgs, err := s.ListPackages()
+	if err != nil {
+		return err
+	}
+
+	for _, pkg := range pkgs {
+		err := s.DeletePackage(pkg.Name, false)
+		if err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
@@ -833,15 +854,26 @@ func (s *serverlessService) DeleteFunction(name string, deleteTriggers bool) err
 	return e
 }
 
-// DeletePackage removes a package and all its namespace from the package from the namespace
-// If force is set to true, it will remove all functions in the package.
-func (s *serverlessService) DeletePackage(name string, force bool) error {
+// ListPackages lists the packages of the namespace
+func (s *serverlessService) ListPackages() ([]whisk.Package, error) {
+	err := initWhisk(s)
+	if err != nil {
+		return []whisk.Package{}, err
+	}
+	options := whisk.PackageListOptions{Limit: 200} // 200 is the max and we are also treating it as a safe-enough value here
+	list, _, err := s.owClient.Packages.List(&options)
+	return list, err
+}
+
+// DeletePackage removes a package from the namespace.
+// If recursive is set to true, it will remove all functions in the package.
+func (s *serverlessService) DeletePackage(name string, recursive bool) error {
 	err := initWhisk(s)
 	if err != nil {
 		return err
 	}
 
-	if force {
+	if recursive {
 		pkg, _, err := s.owClient.Packages.Get(name)
 		if err != nil {
 			return err
@@ -1082,6 +1114,32 @@ func (s *serverlessService) GetTrigger(ctx context.Context, name string) (Server
 	return decoded.Trigger, nil
 }
 
+func (s *serverlessService) UpdateTrigger(ctx context.Context, trigger string, opts *UpdateTriggerRequest) (ServerlessTrigger, error) {
+	empty := ServerlessTrigger{}
+	err := s.CheckServerlessStatus()
+	if err != nil {
+		return empty, err
+	}
+	creds, err := s.ReadCredentials()
+	if err != nil {
+		return empty, err
+	}
+
+	path := fmt.Sprintf("v2/functions/namespaces/%s/triggers/%s", creds.Namespace, trigger)
+	req, err := s.client.NewRequest(ctx, http.MethodPut, path, opts)
+
+	if err != nil {
+		return empty, err
+	}
+
+	decoded := new(ServerlessTriggerGetResponse)
+	_, err = s.client.Do(ctx, req, decoded)
+	if err != nil {
+		return empty, err
+	}
+	return decoded.Trigger, nil
+}
+
 // Delete Trigger deletes a trigger from the namespace (used when undeploying triggers explicitly,
 // not part of a more general undeploy; when undeploying a function or the entire namespace we rely
 // on the deployer to delete associated triggers).
